# Django settings for pv project.

import os
from pathlib import Path

from corsheaders.defaults import default_headers

# Paths
BASE_DIR = Path(__file__).resolve(strict=True).parent.parent

LOCALE_PATHS = (BASE_DIR / "locale",)

MEDIA_ROOT = BASE_DIR / "site_media"
MEDIA_URL = "/site_media/"

STATIC_ROOT = BASE_DIR / "static"
STATIC_URL = "/static/"

ROOT_URLCONF = "steering.urls"

DEBUG = True if os.getenv("DEBUG") else False
SITE_ID = 1
ADMINS = ()
MANAGERS = ADMINS

# Must be set if DEBUG is False
ALLOWED_HOSTS = os.getenv("ALLOWED_HOSTS", default="127.0.0.1,localhost").split(",")

# Whitelist origins that access the API
CORS_ALLOWED_ORIGINS = os.getenv(
    "CORS_ALLOWED_ORIGINS",
    default=os.getenv(
        # This is for backwards compatibility as
        # CORS_ALLOWED_ORIGINS was named CORS_ORIGIN_WHITELIST in the past.
        "CORS_ORIGIN_WHITELIST",
        default=("http://localhost:8080", "http://localhost:8040"),
    ),
)
CORS_ALLOW_CREDENTIALS = True
CORS_ALLOW_HEADERS = list(default_headers) + [
    "content-disposition",
]

# if we are in a virtual environment, we use SQLite and enable debug
if os.getenv("VIRTUAL_ENV"):
    DEBUG = True
    DATABASES = {
        "default": {
            "ENGINE": "django.db.backends.sqlite3",
            "NAME": BASE_DIR / "db.sqlite3",
        }
    }
else:
    DATABASES = {
        "default": {
            "ENGINE": "django.db.backends.postgresql",
            "NAME": os.getenv("POSTGRES_DB", default="steering"),
            "USER": os.getenv("POSTGRES_USER", default="steering"),
            "PASSWORD": os.getenv("POSTGRES_PASSWORD", default="aura"),
            "HOST": os.getenv("POSTGRES_HOST", default="steering-postgres"),
            "PORT": os.getenv("POSTGRES_PORT", default="5432"),
        },
    }

CACHE_BACKEND = "locmem://"

# LOCALIZATION
TIME_ZONE = os.getenv("TIME_ZONE", default="Europe/Vienna")
LANGUAGE_CODE = os.getenv("LANGUAGE_CODE", default="de")
USE_I18N = True
USE_L10N = True

SECRET_KEY = os.getenv("SECRET_KEY", default="secret-key")

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [BASE_DIR / "templates"],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.contrib.auth.context_processors.auth",
                "django.template.context_processors.request",
                "django.template.context_processors.debug",
                "django.template.context_processors.i18n",
                "django.template.context_processors.media",
                "django.template.context_processors.static",
                "django.template.context_processors.tz",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

MIDDLEWARE = (
    "corsheaders.middleware.CorsMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
)

REST_FRAMEWORK = {
    # Use Django's standard `django.contrib.auth` permissions,
    # or allow read-only access for unauthenticated users.
    "DEFAULT_PERMISSION_CLASSES": [
        "rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly"
    ],
    "DEFAULT_AUTHENTICATION_CLASSES": [
        "program.auth.OidcOauth2Auth",
    ],
    "DEFAULT_FILTER_BACKENDS": ["django_filters.rest_framework.DjangoFilterBackend"],
    "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema",
    "EXCEPTION_HANDLER": "steering.views.full_details_exception_handler",
}

SPECTACULAR_SETTINGS = {
    "TITLE": "AURA Steering API",
    "DESCRIPTION": "Programme/schedule management for Aura",
    "POSTPROCESSING_HOOKS": [
        "drf_spectacular.hooks.postprocess_schema_enums",
        "steering.schema.add_enum_documentation",
        "steering.schema.fix_schedule_pk_type",
    ],
    "VERSION": "1.0.0",
}

INSTALLED_APPS = (
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.messages",
    "django.contrib.admin",
    "django.contrib.staticfiles",
    "program",
    "profile",
    "versatileimagefield",
    "rest_framework",
    "rest_framework_nested",
    "django_filters",
    "django_extensions",
    "drf_spectacular",
    "oidc_provider",
    "corsheaders",
)

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"

# Set the desired sizes for your thumbnails (px)
# Will apply to all uploaded images
THUMBNAIL_SIZES = ["640x480", "200x200", "150x150"]

# When generating schedules/timeslots:
# If last_date wasn't set manually, add timeslots until these number of days after the start_date
AUTO_SET_LAST_DATE_TO_DAYS_IN_FUTURE = 365

# If last_date wasn't set manually, add timeslots until the end of the current year
# Overrides the above setting if True
AUTO_SET_LAST_DATE_TO_END_OF_YEAR = True

# URL to CBA - Cultural Broadcasting Archive
CBA_URL = "https://cba.fro.at"

# Contact cba@fro.at to get whitelisted and get an API KEY
# Leave empty to disable requests to CBA
CBA_API_KEY = ""

# URL to CBA ajax handler (used for retrieving additional data or increasing stream counter)
CBA_AJAX_URL = CBA_URL + "/wp-admin/admin-ajax.php"

# URL to CBA's REST API with trailing slash
CBA_REST_API_URL = CBA_URL + "/wp-json/wp/v2/"

# OIDC Provider Settings
USE_TZ = True  # django-oidc-provider needs timezones in database
LOGIN_URL = "/admin/login/"  # Login page OIDC redirects to
OIDC_EXTRA_SCOPE_CLAIMS = "steering.oidc_provider_settings.AuraScopeClaims"

if os.getenv("STEERING_PORT"):
    SITE_URL = (
        os.getenv("AURA_PROTO", default="http")
        + "://"
        + os.getenv("AURA_HOST", default="localhost")
        + ":"
        + os.getenv("STEERING_PORT")
    )
else:
    SITE_URL = (
        os.getenv("AURA_PROTO", default="http")
        + "://"
        + os.getenv("AURA_HOST", default="localhost")
    )

# WSGI_APPLICATION = 'steering.wsgi.application';
